from numpy.random import shuffle


def datasetInfo(dataset):
    """
    Takes the dataset and returns the following statistics as a dictionary:
        rows: number of rows in the dataset
        columns: number of columns in the dataset
        benign: Number of benign entries in dataset
        malignant: Number of malignant entries in dataset
    """
    # return a dictionary
    ret = {}

    ret["rows"] = dataset.shape[0]
    ret["columns"] = dataset.shape[1]
    ret["benign"] = (dataset["diagnosis"] == "B").sum()
    ret["malignant"] = (dataset["diagnosis"] == "M").sum()
    return ret


def splitDataset(dataset, test_percentage=20):
    """
    Takes the dataset as a dataframe

    Shuffles data, then returns 4 subsets of the dataset as numpy matrices:
        Training data without labels (100-test_percentage percent of the data)
        Training data labels (column vector!)
        Testing data without labels (test_percentage percent of the data)
        Testing data labels (column vector!)
    """
    # first, extract the data into numpy from pandas
    mat = dataset.values

    # now shuffle
    shuffle(mat)

    # now slice into training and testing
    testing = mat[: int((test_percentage / 100) * len(mat)), :]
    training = mat[int((test_percentage / 100) * len(mat)) :, :]

    # now slice training into training_data and training_labels
    training_labels = training[:, 0]
    training = training[:, 1:]

    # now slice testing into testing_data and testing_labels
    testing_labels = testing[:, 0]
    testing = testing[:, 1:]

    return training, training_labels, testing, testing_labels
