
import pandas as pd
import seaborn as sns
import matplotlib.pyplot as plt


def readData(filename):
    """return a dataframe with index 'Row ID'"""
    df = pd.read_csv(filename)
    df.set_index("Row ID", inplace=True)
    return df


def filterBy(df, quantity=None, discount=None, profit=None):
    """given the input dataframe, return just the rows where Quantity column is greater than the input variable quantity, and similarly for discount and profit.

    If the value passed in is None, do not filter with it.
    """
    if quantity:
        df = df[df["Quantity"] > quantity]
    if discount:
        df = df[df["Discount"] > discount]
    if profit:
        df = df[df["Profit"] > profit]
    return df


def stateSegmentHeatmap(df):
    """Draw a heatmap with seaborn where:
        - states as row pivots
        - segments as column pivots
        - color by profit

    """
    pt = pd.pivot_table(df, values="Profit", index=["State"], columns=["Segment"])
    sns.heatmap(pt)

    plt.show()

if __name__ == "__main__":
    df = readData("data.csv")

    df1 = filterBy(df, quantity=200)
    print(df1.shape)
    # (788, 18)
    df2 = filterBy(df, quantity=200, discount=50)
    print(df2.shape)
    # (414, 18)

    df3 = filterBy(df, quantity=200, discount=50, profit=300)
    print(df3.shape)
    # (294, 18)

    df4 = filterBy(df, discount=50, profit=300)
    print(df4.shape)
    # (374, 18)

    df5 = filterBy(df, profit=300)
    print(df5.shape)
    # (713, 18)

    df6 = filterBy(df)
    print(df6.shape)
    # (1000, 18)

    stateSegmentHeatmap(df)
