import random


class RandomList(list):
    def __init__(self, data):
        if isinstance(data, int):
            super().__init__([random.randint(0, 100) for _ in range(data)])
        elif isinstance(data, list):
            super().__init__(data[:])
            self.shuffle()
        else:
            raise NotImplementedError

    def __str__(self):
        return "random({})".format(self[:])

    def __repr__(self):
        return "<RandomList {}>".format([_ for _ in self])

    def shuffle(self):
        random.shuffle(self)

    def __add__(self, other):
        if isinstance(other, RandomList):
            data = super().__add__(other)
            random.shuffle(data)
            return RandomList(data)
        if isinstance(other, list):
            return super().__add__(other)
        raise NotImplementedError

if __name__ == "__main__":
    rl1 = RandomList(10)  # creates a RandomList with 10 random integers between 0 and 100
    rl2 = RandomList([1, 2, 3])  # creates a RandomList from this list, shuffling the contents

    try:
        rl3 = RandomList("test")  # throws error
        assert False
    except NotImplementedError:
        print("ok")

    # overload __str__
    print(rl1)
    print(rl2)

    # overload __repr__
    lst = [rl1, rl2]
    print(lst)

    # new method
    print(rl1)
    rl1.shuffle()
    print(rl1)

    # overload +
    print(rl1 + [1, 2, 3])  # make new `list` from rl1's data and the other list
    print(rl1 + rl2)  # make a new RandomList frp, rl1'1 data and the other list, shuffling

    try:
        print(rl1 + "abc")  # throws error
        assert False
    except NotImplementedError:
        print("ok")
